diff -purN u-boot-0.3.0/common/devices.c u-boot-0.3.1/common/devices.c
--- u-boot-0.3.0/common/devices.c	Fri Nov 22 13:49:52 2002
+++ u-boot-0.3.1/common/devices.c	Sun Jun 15 15:28:42 2003
@@ -156,13 +156,15 @@ int devices_init (void)
 	DECLARE_GLOBAL_DATA_PTR;
 
 	int i;
-	ulong relocation_offset = gd->reloc_off;
+#ifndef CONFIG_ARM     /* already relocated for current ARM implementation */	
+    ulong relocation_offset = gd->reloc_off;
 
-	/* relocate device name pointers */
+    /* relocate device name pointers */
 	for (i = 0; i < (sizeof (stdio_names) / sizeof (char *)); ++i) {
 		stdio_names[i] = (char *) (((ulong) stdio_names[i]) +
 						relocation_offset);
 	}
+#endif
 
 	/* Initialize the list */
 	devlist = ListCreate (sizeof (device_t));
diff -purN u-boot-0.3.0/lib_arm/board.c u-boot-0.3.1/lib_arm/board.c
--- u-boot-0.3.0/lib_arm/board.c	Fri Apr  4 17:42:23 2003
+++ u-boot-0.3.1/lib_arm/board.c	Sun Jun 15 15:20:01 2003
@@ -28,6 +28,7 @@
 #include <common.h>
 #include <command.h>
 #include <devices.h>
+#include <syscall.h>
 #include <version.h>
 #include <net.h>
 
@@ -87,8 +88,7 @@ static int init_baudrate (void)
 
 	uchar tmp[64];	/* long enough for environment variables */
 	int i = getenv_r ("baudrate", tmp, sizeof (tmp));
-
-	gd->baudrate = (i > 0)
+   	gd->bd->bi_baudrate = gd->baudrate = (i > 0)
 			? (int) simple_strtoul (tmp, NULL, 10)
 			: CONFIG_BAUDRATE;
 
@@ -238,11 +238,6 @@ void start_armboot (void)
 	/* initialize environment */
 	env_relocate ();
 
-#ifdef CONFIG_VFD
-	/* must do this after the framebuffer is allocated */
-	drv_vfd_init();
-#endif
-
 	/* IP Address */
 	bd_data.bi_ip_addr = getenv_IPaddr ("ipaddr");
 
@@ -263,6 +258,21 @@ void start_armboot (void)
 		}
 	}
 
+#ifdef CONFIG_VFD
+	/* must do this after the framebuffer is allocated */
+	drv_vfd_init();
+#endif
+    
+    devices_init ();      /* get the devices list going. */
+
+    /* Syscalls are not yet implemented for ARM, but probably should be. Allocating
+     *  this allows the console_init routiene's to work with out ifdefs, and will be
+     *  needed with syscalls are finally added (for loadable module support).
+     */
+	syscall_tbl = (void **) malloc (NR_SYSCALLS * sizeof (void *));
+    
+    console_init_r ();
+
 #if defined(CONFIG_MISC_INIT_R)
 	/* miscellaneous platform dependent initialisations */
 	misc_init_r ();
